<?php
/**
 * 2007-2022 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    patworx multimedia GmbH <service@patworx.de>
 *  @copyright 2007-2022 patworx multimedia GmbH
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */
class EasycreditSession
{
    public $data = [];

    protected static $sessionKeys = [
        'technicalTransactionId',
        'transactionId',
        'deviceIdentToken',
    ];
    protected static $instance = null;

    /**
     * Set possible session data
     */
    public function __construct()
    {
        foreach (self::$sessionKeys as $sessionKey) {
            $checkVar = 'easycredit_' . $sessionKey;
            if (isset(Context::getContext()->cookie->$checkVar)) {
                $this->data[$sessionKey] = Context::getContext()->cookie->$checkVar;
            }
        }
    }

    /**
     * @return EasycreditSession|null
     */
    public static function getInstance()
    {
        if (is_null(self::$instance)) {
            $instance = new self();
            self::$instance = $instance;
        }

        return self::$instance;
    }

    /**
     * @param false $write
     */
    public function reset($write = false)
    {
        $this->data = [];
        foreach (self::$sessionKeys as $sessionKey) {
            $checkVar = 'easycredit_' . $sessionKey;
            unset(Context::getContext()->cookie->$checkVar);
        }
        if ($write) {
            Context::getContext()->cookie->write();
        }
    }

    /**
     * @param $var
     * @param $val
     *
     * @return $this
     */
    public function set($var, $val)
    {
        if (in_array($var, self::$sessionKeys)) {
            $this->data[$var] = $val;
            $sessionVar = 'easycredit_' . $var;
            Context::getContext()->cookie->$sessionVar = $val;
        }

        return $this;
    }

    /**
     * @param $var
     * @param false $default
     *
     * @return false|mixed
     */
    public function get($var, $default = false)
    {
        if (in_array($var, self::$sessionKeys)) {
            if (isset($this->data[$var])) {
                return $this->data[$var];
            }
        }

        return $default;
    }
}
