<?php
/**
* 2007-2019 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2019 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/
class EasycreditratenkaufConfirmationModuleFrontController extends ModuleFrontController
{
    use EasycreditRedirectionTrait;

    public function postProcess()
    {
        $fetchRequestResponse = EasycreditClient::getInstance()->fetchTransaction(
            EasycreditSession::getInstance()->get('technicalTransactionId')
        );

        $fetchRequestResponse = json_decode($fetchRequestResponse, true);

        $is_valid = true;
        if (!isset($fetchRequestResponse['status'])) {
            $is_valid = false;
        }
        if ($fetchRequestResponse['status'] != 'PREAUTHORIZED') {
            $is_valid = false;
        }
        if (!isset($fetchRequestResponse['decision'])) {
            $is_valid = false;
        }
        if (!isset($fetchRequestResponse['decision']['decisionOutcome'])) {
            $is_valid = false;
        }
        if ($fetchRequestResponse['decision']['decisionOutcome'] != 'POSITIVE') {
            $is_valid = false;
        }

        if (!$is_valid) {
            $this->errorRedirect();
        }

        $authorization = EasycreditClient::getInstance()->authorizeTransaction(
            EasycreditSession::getInstance()->get('technicalTransactionId')
        );
        if ($authorization != '202') {
            $this->errorRedirect();
        }

        $cart = Context::getContext()->cart;
        $customer = new Customer((int) $cart->id_customer);
        $secure_key = $customer->secure_key;

        $payment_status = Configuration::get('PS_OS_PAYMENT');

        $module_name = $this->module->displayName;
        $currency_id = (int) Context::getContext()->currency->id;

        $this->module->validateOrder(
            (int) $cart->id,
            $payment_status,
            (float) $fetchRequestResponse['decision']['orderValue'],
            $module_name,
            '',
            [],
            $currency_id,
            false,
            $customer->secure_key
        );

        $order_id = (int) $this->module->currentOrder;

        if ($order_id) {
            EasycreditLog::updateOrderIdForVorgang($order_id, EasycreditSession::getInstance()->get('technicalTransactionId'));
        }

        EasycreditSession::getInstance()->reset();

        if ($order_id && ($secure_key == $customer->secure_key)) {
            $module_id = $this->module->id;
            Tools::redirect('index.php?controller=order-confirmation&id_cart=' . $cart->id . '&id_module=' . $module_id . '&id_order=' . $order_id . '&key=' . $secure_key);
        }
        $this->errorRedirect();
    }
}
